package
Version:
v0.0.0-...-1d50835
Opens a new window with list of versions in this module.
Published: Mar 5, 2020
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type GetTargetTemperatureResponse struct {
TargetTemperature float64 `json:"target_temperature"`
CurrentTemperature float64 `json:"current_temperature"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.